# Shareable Links:
A list of links to share the selected document.


## Columns:
Each column title has three lines on the right if you hover over it. Click on them to show options for that column. The second tab of the options menu will allow you to filter the column, the third to completely hide entire columns. Click on anywhere else on the column to order it, cycling between ascending, descending and no ordering. Hold shift while clicking to order multiple columns with individual weights.
### Valid Until:
Date and time at which the link loses its validity.
### One Time Link:
Specifies if the link can be accessed only one time or and infinite amount.
### Link:
The URL under which the document can be accessed.

## Buttons:
### Invalidate:
Invalidate the selected link manually even if the validation date lies in the future.

## Legend:
Click on the legend to filter by link validity.

## Filters:
### Valid:
Filter by link validity.
### Document:
Display links for a specific document. Will default to the current document displayed.

## Search Field:
Typing in the search field allows to filter by link uuid.
